<!-- For Guppy, this file must be put in inc/incpage   -->

<?php
/*
Fork for Guppy 5.0.7 : FB_og_meta, by C.Mineau www.labellenote.fr
V1.0 : articles only
V2.0 : articles and news (when displayed as single news)
V2.1 : bug fix on regexp to find the image
V2.2 : security script name check + install in inc/incpage
V2.3 : add og:image:width tag + fix image search pattern + refactoring Guppy 5.2.8
V2.4 : https
V2.5 : fix mime constant, deprecated
The aim is to introduce the meta tags required by the facebook Open Graph API in order to select what are the details to be shared 
on a particular page : 
title/ description / site name / picture
These informations must appear in a meta tag with attribute property="og:xxxx" in the <head> tag.

Proposed mapping, for an Article or news :
og:site_name => the name of the site
og:url  ==> url of article or url of single news 
og:type ==> article (constant)
og:title ==> The title of the Guppy article / single news 
og:image ==> First image in the article with alt field == "FB"   (put FB in the Guppy image editor in the field 'Alternative text')
og:description == > First lines of the article + invitation to read the article on the site
og:locale ==> "fr_FR"  or "en_US" 
*/


function FB_find_image($txt, $default)  // finds the first image in the doc, with alt field ="FB"
{
	$imgRegexp = '#<img.*alt="FB" src="(.*?)".*>#';  // search for the url of the image having FB as alt attribute
	if (preg_match($imgRegexp, $txt, $out)) {
		$img=$out[1];
	} else { 
        $imgRegexp = '#<img.*src="(.*?)".*alt="FB".*>#';  // search for the url of the image having FB as alt attribute
        if (preg_match($imgRegexp, $txt, $out)) 
            $img=$out[1];
         else 
            $img=$default;
    }
	return $img;
}
function wd_remove_accents($str, $charset='utf-8')
// credit : http://www.weirdog.com/blog/php/supprimer-les-accents-des-caracteres-accentues.html
{
	$str = htmlentities($str, ENT_NOQUOTES, $charset);

	$str = preg_replace('#&([A-za-z])(?:acute|cedil|caron|circ|grave|orn|ring|slash|th|tilde|uml);#', '\1', $str);
	$str = preg_replace('#&([A-za-z]{2})(?:lig);#', '\1', $str); // pour les ligatures e.g. '&oelig;'
	$str = preg_replace('#&[^;]+;#', '', $str); // supprime les autres caractres

	return $str;
}


// security scripname check, by Saxbar : 
if (stristr($_SERVER['SCRIPT_NAME'], 'FB_og_meta.inc')) {
  header('location:../index.php');
  die(); 
} else {
  echo '<!-- Start of code generated by the FB_og_meta fork --> ';
}


$FBurl="https://".$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI']; 
$FBsitename=$site[0];
$FBdescription='nothing';
$FBlocale = "";
$FBtitle = "";
$FBimage = "";

// get the document if article or single news
if ($pg != null) {
	$isart = count(SelectDBFields(TYP_ART, 'a', $pg)) == 1;
	$isnews = count(SelectDBFields(TYP_NEWS, 'a', $pg)) == 1;
	if ($isart || $isnews) {
		// read the doc
		ReadDoc($pg);
		
		if ($lng=="fr") {
			$FBdescription=strip_tags($fieldc1);
			$FBdescription = preg_replace ("/\s+/", " ",$FBdescription );
			$FBdescription = preg_replace ("/\"+/", "", $FBdescription);
			$FBdescription = preg_replace ("/(&nbsp;)+/", " ", $FBdescription);
			$FBdescription = wd_remove_accents($FBdescription);
			$FBdefault_image="skins/skin01_LBN_2014/img/photo.jpg";
			$FBlocale="fr_FR";
			$image = FB_find_image($fieldc1, $FBdefault_image);
			$FBimage="https://".$_SERVER['HTTP_HOST'].$_SERVER['CONTEXT_PREFIX']."/".$image;
			$FBtitle=strip_tags($fieldb1);
			$FBtitle=wd_remove_accents($FBtitle);
			$FBdescription=substr($FBdescription,0,200)." ... lire la suite ...";
			
		} elseif ($lng=="en") { // en
			$FBdescription=strip_tags($fieldc2);
			$FBdescription = preg_replace ("/\s+/", " ",$FBdescription );
			$FBdescription = preg_replace ("/\"+/", "", $FBdescription);
			$FBdescription = preg_replace ("/(&nbsp;)+/", " ", $FBdescription);
			$FBdescription = wd_remove_accents($FBdescription);
			$FBdefault_image="skins/skin01_LBN_2014/img/photo.jpg";
			$FBlocale="en_US";
			$image = FB_find_image($fieldc2, $FBdefault_image);
			$FBimage="https://".$_SERVER['HTTP_HOST'].$_SERVER['CONTEXT_PREFIX']."/".$image;
			$FBtitle=strip_tags($fieldb2);
			$FBtitle=wd_remove_accents($FBtitle);
			$FBdescription=substr($FBdescription,0,200)." ... read more ...";
		}
		// image size tags
		$size = getimagesize($image);
		// Display meta tags  (width / height doesn't work ?)
		// <meta property="og:image:width" content=200 />
		// <meta property="og:image:height" content=300 />
		if ($FBdescription != 'nothing') {
			echo'
<meta property="og:locale" content="'.$FBlocale.'" />
<meta property="og:site_name" content="'.$FBsitename.'"/>
<meta property="og:url" content="'.$FBurl.'"/>
<meta property="og:type" content="article"/>
<meta property="og:title" content="'.$FBtitle.'"/>
<meta property="og:image:type" content="'.$size['mime'].'" />
<meta property="og:image:width" content="'.$size[0].'" />
<meta property="og:image:height" content="'.$size[1].'" />
<meta property="og:image:url" content="'.$FBimage.'"/>
<meta property="og:description" content="'.$FBdescription.'"/>
';			
		}
	}
}


echo '<!-- End of code generated by the FB_og_meta fork --> ';


?>